@@ -36,10 +36,10 @@
 
 namespace octomap {
 
-	OcTree::OcTree(double resolution) 
-		: OccupancyOcTreeBase<OcTreeNode>(resolution) {
+	OcTree::OcTree(double in_resolution)
+		: OccupancyOcTreeBase<OcTreeNode>(in_resolution) {
 		ocTreeMemberInit.ensureLinking();
-	};
+	}
 
   OcTree::OcTree(std::string _filename)
     : OccupancyOcTreeBase<OcTreeNode> (0.1)  { // resolution will be set according to tree file
@@ -48,7 +48,7 @@ namespace octomap {
 
   OcTree::StaticMemberInitializer OcTree::ocTreeMemberInit;
 
-  
+
 
 
 } // namespace
