@@ -38,11 +38,16 @@
 
 #if defined(_MSC_VER) || defined(_LIBCPP_VERSION)
   #include <algorithm>
+  #if __cplusplus > 199711L
+    #include <random>
+  #endif
 #else
   #include <ext/algorithm>
 #endif
 #include <fstream>
 #include <math.h>
+#include <assert.h>
+#include <limits>
 
 #include <octomap/Pointcloud.h>
 
@@ -208,7 +213,13 @@ namespace octomap {
   #if defined(_MSC_VER) || defined(_LIBCPP_VERSION)
     samples.reserve(this->size());
     samples.insert(samples.end(), this->begin(), this->end());
-    std::random_shuffle(samples.begin(), samples.end());
+    #if __cplusplus > 199711L
+      std::random_device r;
+      std::mt19937 urbg(r());
+      std::shuffle(samples.begin(), samples.end(), urbg);
+    #else
+      std::random_shuffle(samples.begin(), samples.end());
+    #endif
     samples.resize(num_samples);
   #else
     random_sample_n(begin(), end(), std::back_insert_iterator<point3d_collection>(samples), num_samples);
@@ -284,14 +295,14 @@ namespace octomap {
 
   std::istream& Pointcloud::readBinary(std::istream &s) {
 
-    unsigned int pc_size = 0;
+    uint32_t pc_size = 0;
     s.read((char*)&pc_size, sizeof(pc_size));
     OCTOMAP_DEBUG("Reading %d points from binary file...", pc_size);
 
     if (pc_size > 0) {
       this->points.reserve(pc_size);
       point3d p;
-      for (unsigned int i=0; i<pc_size; i++) {
+      for (uint32_t i=0; i<pc_size; i++) {
         p.readBinary(s);
         if (!s.fail()) {
           this->push_back(p);
@@ -302,6 +313,8 @@ namespace octomap {
         }
       }
     }
+    assert(pc_size == this->size());
+    
     OCTOMAP_DEBUG("done.\n");
 
     return s;
@@ -310,8 +323,15 @@ namespace octomap {
 
   std::ostream& Pointcloud::writeBinary(std::ostream &s) const {
 
-    size_t pc_size = this->size();
-    OCTOMAP_DEBUG("Writing %lu points to binary file...", (unsigned long)pc_size);
+    // check if written unsigned int can hold size
+    size_t orig_size = this->size();
+    if (orig_size > std::numeric_limits<uint32_t>::max()){
+      OCTOMAP_ERROR("Pointcloud::writeBinary ERROR: Point cloud too large to be written");
+      return s;
+    }
+    
+    uint32_t pc_size = static_cast<uint32_t>(this->size());
+    OCTOMAP_DEBUG("Writing %u points to binary file...", pc_size);
     s.write((char*)&pc_size, sizeof(pc_size));
 
     for (Pointcloud::const_iterator it = this->begin(); it != this->end(); it++) {
