@@ -40,7 +40,7 @@
 using namespace std;
 using namespace octomap;
 
-int main(int argc, char** argv) {
+int main(int /*argc*/, char** /*argv*/) {
 
   cout << "generating example map" << endl;
 
