@@ -17,7 +17,7 @@ void print_query_info(point3d query, ColorOcTreeNode* node) {
 }
 
 
-int main(int argc, char** argv) {
+int main(int /*argc*/, char** /*argv*/) {
 
   double res = 0.05;  // create empty tree with resolution 0.05 (different from default 0.1 for test)
   ColorOcTree tree (res);
